# The ELIT Project [![Build Status](https://travis-ci.org/elitcloud/elit.svg?branch=master)](https://travis-ci.org/elitcloud/elit) [![PyPI version](https://badge.fury.io/py/elit.svg)](https://badge.fury.io/py/elit) [![Documentation Status](https://readthedocs.org/projects/elit/badge/?version=latest)](http://elit.readthedocs.io/en/latest/?badge=latest)


The **E**mory **L**anguage **I**nformation **T**oolkit or **E**volution of **L**anguage and **I**nformation **T**echnology (ELIT) project provides:

* NLP tools readily available for research in various disciplines.
* Frameworks for fast development of efficient and robust NLP components.

The project is initiated and currently led by the [Emory NLP](http://nlp.mathcs.emory.edu) research group. It is under the [Apache 2](http://www.apache.org/licenses/LICENSE-2.0) license. Please join our group to get notifications about updates and send us your feedback.

## Installation

```
pip install elit
```

## Docs

Please visit: https://elit.readthedocs.io/


## Issues


If you have any question or want to report bugs, please let us know on [github issues](https://github.com/elitcloud/elit/issues).


## Contribution 

We appreciate contributions. If you want to contribute to ELIT, please be sure to read our [contribution guidelines](CONTRIBUTING.md) first. 

To setup the development environment, please read [development guidelines](DEVELOPMENT.md)  

## License

[Apache License 2.0](LICENSE)